@@ -1,12 +1,12 @@
-import {expectType} from 'tsd-check';
-import pLimit from '.';
+import {expectType} from 'tsd';
+import pLimit = require('.');
 
 const limit = pLimit(1);
 
 const input = [
 	limit(() => Promise.resolve('foo')),
 	limit(() => Promise.resolve('bar')),
-	limit(() => Promise.resolve(undefined)),
+	limit(() => Promise.resolve(undefined))
 ];
 
 expectType<Promise<Array<string | undefined>>>(Promise.all(input));
@@ -16,3 +16,5 @@ expectType<Promise<string>>(limit((a: string, b: number) => Promise.resolve(''),
 
 expectType<number>(limit.activeCount);
 expectType<number>(limit.pendingCount);
+
+expectType<void>(limit.clearQueue());
